==> mediawiki-1.12.0.tar.gz: mediawiki-1.12.0/languages/messages/MessagesNa.php <==
<?php
/** Nauru (Ekakairũ Naoero)
 *
 * @addtogroup Language
 *
 * @author CdaMVvWgS
 * @author Belgian man
 * @author Node ue
 * @author SPQRobin
 */

$messages = array(
# Dates
'sunday'    => 'Tondak',
'monday'    => 'Mondak',
'tuesday'   => 'Dintak',
'wednesday' => 'Mitwok',
'thursday'  => 'Donertak',
'friday'    => 'Preidak',
'saturday'  => 'Tadurdei',

'qbedit'        => 'Kiwiwid',
'moredotdotdot' => 'Iyuw...',
'and'           => 'me',

'errorpagetitle' => 'Dairinaiya',
'help'           => 'Ipuok',
'search'         => 'Kanani',
'go'             => 'Nuwa ko!',
'history_short'  => 'Ekadaedaenigawae',
'edit'           => 'Kiwiwid',
'delete'         => 'Iyababa',
'unprotect'      => 'Eab oberei',
'toolbox'        => 'Dabadi n bwait makur',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Imwin',
'currentevents-url' => 'Project:Imwin',
'edithelp'          => 'Oomo/edar Ipuok',
'edithelppage'      => 'Help:Oomo/edar',
'helppage'          => 'Help:Oangan',
'mainpage'          => 'Bwiema peij',
'sitesupport'       => 'Eadu a me',

'editsection' => 'Kiwiwid',
'showtoc'     => 'oduwen',
'hidetoc'     => 'ewewin',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-help' => 'Ipuok',

# General errors
'error' => 'Dairinaiya',

# Login and logout pages
'login'        => 'Metu',
'logout'       => 'Meta',
'userlogout'   => 'Meta',
'yourlanguage' => 'Edorer',

# Edit page toolbar
'bold_sample'  => 'Eõ mangiyungiy',
'bold_tip'     => 'Eõ mangiyungiy',
'image_sample' => 'Ekar.jpg',

# Edit pages
'savearticle'    => 'Otsimor',
'newarticle'     => '(Etsimeduw)',
'editing'        => 'Oomo/edar $1',
'editingsection' => 'Oomo/edar $1 (itubwang)',

# Search results
'powersearch' => 'Anani ko',

# Preferences page
'skin'              => 'Witsin',
'searchresultshead' => 'Anani ko',

# Recent changes
'recentchanges' => 'Iwiwidit tsimeduw',
'hist'          => 'eka',
'hide'          => 'witsit imin gogoro',
'show'          => 'oduwen',

# Image list
'ilsubmit'  => 'Anani ko',
'byname'    => 'ean eg',
'imgdelete' => 'iya',

# Random page
'randompage' => 'Tamo peij',

# Miscellaneous special pages
'move' => 'Memori',

# Special:Allpages
'allpagessubmit' => 'nuwa ko',

# E-mail user
'emailuser' => 'Emaileiy amune',
'emailfrom' => 'Atsiu',
'emailto'   => 'Animwen',
'emailsend' => 'Oiyon',

# Watchlist
'watch'   => 'Aea',
'unwatch' => 'Eab krak',

# Delete/protect/revert
'confirm'        => 'Oebwigaga',
'deletedarticle' => 'iyababa "[[$1]]"',

# Contributions
'contributions' => 'Mana engame totow inne',

);

==> mediawiki-1.14.0.tar.gz: mediawiki-1.14.0/languages/messages/MessagesNa.php <==
<?php
/** Nauru (Dorerin Naoero)
 *
 * @ingroup Language
 * @file
 *
 * @author Belgian man
 * @author CdaMVvWgS
 * @author Node ue
 */

$messages = array(
# Dates
'sunday'    => 'Tondak',
'monday'    => 'Mondak',
'tuesday'   => 'Dintak',
'wednesday' => 'Mitwok',
'thursday'  => 'Donertak',
'friday'    => 'Preidak',
'saturday'  => 'Tadurdei',

'qbedit'        => 'Kiwiwid',
'moredotdotdot' => 'Iyuw...',
'and'           => '&#32;me',

'errorpagetitle' => 'Dairinaiya',
'help'           => 'Ipuok',
'search'         => 'Kanani',
'go'             => 'Nuwa ko!',
'history_short'  => 'Ekadaedaenigawae',
'edit'           => 'Kiwiwid',
'delete'         => 'Iyababa',
'unprotect'      => 'Eab oberei',
'toolbox'        => 'Dabadi n bwait makur',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Imwin',
'currentevents-url'    => 'Project:Imwin',
'edithelp'             => 'Oomo/edar Ipuok',
'edithelppage'         => 'Help:Oomo/edar',
'helppage'             => 'Help:Oangan',
'mainpage'             => 'Bwiema peij',
'mainpage-description' => 'Bwiema peij',

'editsection' => 'Kiwiwid',
'showtoc'     => 'oduwen',
'hidetoc'     => 'ewewin',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-help' => 'Ipuok',

# General errors
'error' => 'Dairinaiya',

# Login and logout pages
'login'        => 'Metu',
'logout'       => 'Meta',
'userlogout'   => 'Meta',
'yourlanguage' => 'Edorer',

# Edit page toolbar
'bold_sample'  => 'Eõ mangiyungiy',
'bold_tip'     => 'Eõ mangiyungiy',
'image_sample' => 'Ekar.jpg',

# Edit pages
'savearticle'    => 'Otsimor',
'newarticle'     => '(Etsimeduw)',
'editing'        => 'Oomo/edar $1',
'editingsection' => 'Oomo/edar $1 (itubwang)',

# Search results
'searchhelp-url' => 'Help:Oangan',
'powersearch'    => 'Anani ko',

# Preferences page
'skin'              => 'Witsin',
'searchresultshead' => 'Anani ko',

# Recent changes
'recentchanges' => 'Iwiwidit tsimeduw',
'hist'          => 'eka',
'hide'          => 'witsit imin gogoro',
'show'          => 'oduwen',

# Random page
'randompage' => 'Tamo peij',

# Miscellaneous special pages
'move' => 'Memori',

# Special:AllPages
'allpagessubmit' => 'nuwa ko',

# E-mail user
'emailuser' => 'Emaileiy amune',
'emailfrom' => 'Atsiu',
'emailto'   => 'Animwen',
'emailsend' => 'Oiyon',

# Watchlist
'watch'   => 'Aea',
'unwatch' => 'Eab krak',

# Delete
'confirm'        => 'Oebwigaga',
'deletedarticle' => 'iyababa "[[$1]]"',

# Contributions
'contributions' => 'Mana engame totow inne',

# Special:NewFiles
'ilsubmit' => 'Anani ko',

);
